mound.jump <- 
# Compute the ballistic trajectory of a jet formed by the 
# flow of an avalanche that hits a braking mound or a dam
function(u0,beta,h,psi,k,fph=0.004,dt=0.1)
{
	if (any(u0<0) || any(u0>999)) 
		stop("u0 cannot be outside the range [0,999]")
	if (any(beta<0) || any(beta>pi/2)) 
		stop("beta cannot be outside the range [0,pi/2]")
	if (any(h<0) || any(h>999)) 
		stop("h cannot be outside the range [0,999]")
	if (any(psi<0) || any(psi>pi/2)) 
		stop("psi cannot be outside the range [0,pi/2]")
	if (any(k<0) || any(k>1)) 
		stop("k cannot be outside the range [0,1]")
	if (!missing(k)) { 
		if (any(fph<0) || any(fph>0.1)) 
			stop("fph cannot be outside the range [0,0.1]")
        }
	if (!missing(dt)) { 
		if (any(dt<0) || any(dt>10)) 
			stop("dt cannot be outside the range [0,10]")
	}
        assign("gcpsi.mound.jump",9.82*cos(psi),envir=sys.frame(1))
        assign("gspsi.mound.jump",9.82*sin(psi),envir=sys.frame(1))
        assign("fph.mound.jump",fph,envir=sys.frame(1))
        dfun <- function(x,y) { u <- sqrt(y[3]^2+y[4]^2)
                c(y[3],y[4],gspsi.mound.jump-fph.mound.jump*u*y[3],
                -gcpsi.mound.jump-fph.mound.jump*u*y[4]) }
        u1 <- k*sqrt(u0^2-2*h*gcpsi.mound.jump)
        t <- 0
        y <- c(0,h,u1*cos(beta),u1*sin(beta))
        tt <- t
        xx <- y[1]
        yy <- y[2]
        ux <- y[3]
        uy <- y[4]
        uu <- u1
        while (y[2]>=0.0) {
                y <- viadam.runge.kutta(t,dt,y,dfun)
                t <- t+dt
                #print (paste(t,y[1],y[2],y[3],y[4]))
                #print (dfun(t,y))
                xx <- c(xx,y[1])
                yy <- c(yy,y[2])
                ux <- c(ux,y[3])
                uy <- c(uy,y[4])
                uu <- c(uu,sqrt(y[3]^2+y[4]^2))
        }
        l <- length(yy)
        x2 <- approx(yy[(l-1):l],xx[(l-1):l],xout=0)$y
        ux2 <- approx(yy[(l-1):l],ux[(l-1):l],xout=0)$y
        uy2 <- approx(yy[(l-1):l],uy[(l-1):l],xout=0)$y
        betalnd <- atan(-uy2/ux2)
        u2 <- sqrt(ux2^2+uy2^2)
        res <- c(u1,x2,x2*cos(psi),u2,betalnd)
        names(res) <- c("u1","x2","x2cpsi","u2","betalnd")
        par <- c(u0,beta,h,psi,k,fph,dt)
        names(par) <- c("u0","beta","h","psi","k","fph","dt")
        list(par=par,res=res,x=xx,y=yy,u=uu)
}
