"obliquenshock" <- 
# compute various characteristics of an oblique shock 
# as functions of the deflecting angle (phi) and Froude number (F)
# using an approximation based on the flow against a normal shock
# with the speed of the normal component of the oblique flow
function(phi, Fr) {
if (any(phi<0) || any(phi>pi/2)) 
   stop("phi cannot be outside the range [0,pi/2]")
if (any(Fr<0) || any(Fr>999)) 
   stop("Fr cannot be outside the range [0,999]")
csphi <- cos(phi)
snphi <- sin(phi)
Fp <- Fr*snphi
Fp2 <- Fp^2
alfa  <- pi/6 - atan((9*Fp2-8)/Fp/sqrt(27*(16+(13+8*Fp2)*Fp2)))/3
h2ph1 <- (2*sqrt(6*Fp2+4)*cos(alfa)+1)/3
philt90 <- phi < pi/2-.Machine$double.eps
dlt   <- ifelse(philt90,csphi*snphi/(csphi^2*h2ph1-1),0)
if (any(dlt<0)) dlt[dlt<0] <- 0
teta  <- phi+dlt
cs <- cos(teta)
sn <- sin(teta)
tn <- tan(teta)
tndlt  <- dlt  # to the same approximation as other quantities
tndlt2 <- tndlt^2
csdlt <- sqrt(1/(1+tndlt2))
sndlt <- sqrt(tndlt2/(1+tndlt2))
ret <- data.frame(teta=teta, phi=phi, delta=dlt, h2ph1=h2ph1, 
  u2pu1=ifelse(philt90,cs/csdlt,0), 
  h2u2ph1u1=ifelse(philt90,sn/sndlt,0))
attr(ret,"Fr") <- Fr
attr(ret,"Fp") <- Fp
ret
}
