"phi2phi" <- 
# convert from a deflecting angle in a sloping coordinate system aligned 
# with the terrain (phi) to deflecting angle in a horizontal projection
# (phih), that is the angle between the avalanche direction and the dam
# axis in the map plane, or the other way around
function(phi,phih,psi) {
if (!missing(phi)) {
   if (any(phi<0) || any(phi>pi/2)) 
      stop("phi cannot be outside the range [0,pi/2]")
}
if (!missing(phih)) {
   if (any(phih<0) || any(phih>pi/2)) 
      stop("phih cannot be outside the range [0,pi/2]")
}
if (any(psi<0) || any(psi>pi/2)) 
   stop("psi cannot be outside the range [0,pi/2]")
ret <- NULL
if (!missing(phi) && !missing(phih)) stop("only one of phi or phih may be specified")
else if (!missing(phi)) { ret <- atan(tan(phi)/cos(psi)) }
else if (!missing(phih)) { ret <- atan(tan(phih)*cos(psi)) }
else stop("neither phi nor phih is given")
ret
}
