"vdamheightngi" <- 
# vertical dam height according to a formula from NGI reports 
# (equivalent to the function vdamheight) computed from dam height normal
# to the terrain (h), deflecting angle with respect to the direction of steepest
# decent in a sloping coordinate system aligned with the terrain (phi), 
# the slope of the terrain (psi), and the angle of the dam side with 
# respect to the sloping terrain in the direction normal to the dam axis,
# this function is only defined for validation purposes
function(phi,psi,alfa,h) {
if (any(phi<0) || any(phi>pi/2)) 
   stop("phi cannot be outside the range [0,pi/2]")
if (any(psi<0) || any(psi>pi/2)) 
   stop("psi cannot be outside the range [0,pi/2]")
if (any(alfa<0) || any(alfa>pi/2)) 
   stop("alfa cannot be outside the range [0,pi/2]")
if (any(h<0) || any(h>999)) 
   stop("h cannot be outside the range [0,999]")
gx <- cos(phi)*sin(psi)
gy <- -cos(psi)*sin(alfa)+sin(phi)*sin(psi)*cos(alfa)
gz <- -cos(psi)*cos(alfa)-sin(phi)*sin(psi)*sin(alfa)
xi <- acos((gy^2+gz^2)/sqrt(1-gx^2-gx^2*gz^2))
hd <- (cos(psi)*sin(alfa)-sin(phi)*sin(psi)*cos(alfa)+tan(xi)*cos(phi)*sin(psi))*h/sin(alfa)
hd
}
