\name{runuph}
\alias{runuph}

\title{Run-up height of an avalanche on a dam or an obstacle.}
\description{Run-up height of an avalanche on a dam or an obstacle corresponding 
to both supercritical overflow and downstream thickness of a shock.
}

\usage{ 
runuph(phih,u1,h1,psi,psip,alfa,k,kp,xi,hs)
}

\arguments{
\item{phih}{deflecting angle with respect to the direction of steepest decent in the map plane, that is the angle between the horizontal projections of the avalanche direction and the dam axis.}
\item{u1}{upstream velocity in metres per second.}
\item{h1}{upstream flow depth in metres.}
\item{psi}{the slope of the terrain.}
\item{psip}{the slope of the terrain in the direction normal to the dam.}
\item{alfa}{the angle of the dam side with respect to the sloping terrain in the direction normal to the dam axis in a plane normal to the upstream terrain.}
\item{k}{a dimensionless coefficient representing momentum loss normal to the dam axis in the impact, computed from \code{alfa} if not specified.}
\item{kp}{curvature of the dam axis for a deflecting dam, equal to one over the radius of curvature, set to zero if not specified.}
\item{xi}{distance along the dam from its upstream end or the upstream end of the impact with the avalanche, set to zero if not specified.}
\item{hs}{snow depth and thickness of previous avalanche deposits on the terrain, set to zero if not specified.}
}

\value{The function returns a dataframe with variables/columns describing supercritical overflow and shock that may be formed by the upstream dam face. The variables of the returned dataframe are:

\item{phi}{deflecting angle with respect to the direction of steepest decent in a sloping coordinate system aligned with the terrain.}
\item{Fr1}{upstream Froude number.}
\item{u1n}{velocity normal to the dam axis.}
\item{Fr1n}{\dQuote{Froude number} in the direction normal to the dam axis.}
\item{Hcr}{critical dam height.}
\item{hcr}{critical flow depth.}
\item{hrp}{supercritical run-up, \emph{i.e.}\ \eqn{H_{cr}}{Hcr} + \eqn{h_{cr}}{hcr}.}
\item{teta}{shock angle.}
\item{delta}{shock widening, \emph{i.e.}\ the angle subtended by the shock with respect to the dam.}
\item{h2}{flow depth downstream of a shock.}
\item{u2}{flow velocity downstream of a shock.}
\item{dHslp}{extra run-up due to slope towards the dam for a deflecting dam.}
\item{dHcrv}{extra run-up due to dam curvature for a deflecting dam.}
\item{hrmx}{maximum of supercritical run-up and flow depth downstream of a shock plus extra run-up due to slope towards the dam and dam curvature for a deflecting dam and plus snow depth on the terrain (in the sloping coordinate system aligned with the terrain).}
\item{hd}{vertical runup corresponding to \code{hrmx}.}

The attribute \code{par} of the returned variable contains the arguments of the call to the function, also as a dataframe.
}
\author{Tomas Johannesson}

\examples{
\dontrun{
runuph(18*pi/180,45,2,11*pi/180,3*pi/180,35*pi/180,hs=3)
}
}

\note{In contrast to most of the other functions in the \code{viadam} library, this function accepts dimensional arguments (\emph{e.g.}\ flow depth in metres and velocity in metres per second) and returns dimensional quantities (\emph{e.g.}\ dam height in metres). Most of the other functions accept non-dimensional quantities such as Froude numbers and angles and return non-dimensional quantities such as the downstream flow depth \eqn{h_2}{h2} relative to the upstream flow depth \eqn{h_1}{h1}.

The arguments \code{k}, \code{kp}, \code{xi} and \code{hs} are optional and have default values that are described above. They should be named ef they are specified (see example with \code{hs} specified in the Examples section).
}

\seealso{\code{\link{obliquenshock}}, \code{\link{mxphi}} and \code{\link{vdamheight}}.}

\keyword{math}
