\name{viadam.runge.kutta}
\alias{viadam.runge.kutta}

\title{Fourth-order Runge-Kutta integration}
\description{One step of the fourth-order Runge-Kutta integration
algorithm for a first order system of differential equations.
}

\usage{ 
viadam.runge.kutta(x,dx,y,f)
}

\arguments{
\item{x}{the starting point of the integration.}
\item{dx}{the step size in \code{x}.}
\item{y}{the initial value of the solution at \code{x}
(a vector of the same length as the number of equations).}
\item{f}{a function expressing the derivative of \code{y} with respect
to \code{x} as a function of \code{x} and \code{y},
that is the right hand side of the differential equation 
\eqn{y^\prime = f(x,y)}{\code{dy/dx = f(x,y)}}.
\code{f} must be defined as a function of two arguments
(a single number \code{x} and a vector \code{y} of the same
length as the number of equations) returning a vector (of the
same length as the number of equations).}
}

\value{The function returns the solution \code{y} at \code{x+dx}.
}
\author{Tomas Johannesson}

\examples{
\dontrun{
yp <- function(x,y) {c(y[2],y[1])}
n <- 10; dx <- 1/n; x <- 0; y <- c(1,1)
for (i in 1:n) { y <- viadam.runge.kutta(x,dx,y,yp); x <- x+dx }
y[1]
y[1]-exp(1)
}
}

\note{\code{viadam.runge.kutta} is typically called repeatedly increasing the value of \code{x}
by \code{dx} in every iteration as shown in the example. The argument
\code{f} must be a function object, which can either be defined beforehand
and referred to by its name, or be defined on the fly as in

\code{viadam.runge.kutta(x,dx,y,(function(x,y){y}))}.

This function is written for use in the function \code{\link{mound.jump}} and is not intended for other use. It is included in the \code{viadam} package to make the package independent of any other utility package for R. There are many other packages that contain good Runge-Kutta integration routines that are more suitable for general use for solving differential equations. This routine is, however, good enough for the problem that needs to be solved in \code{\link{mound.jump}}.
}

\seealso{\code{\link{mound.jump}}.}

\keyword{internal}
